@@ -11,7 +11,10 @@ observeEvent(input$analyzeBtn, {
         html("analyzeProgress", m$message, TRUE)
       },
       warning = function(m) {
-        html("analyzeProgress", paste0(m$message, "\n"), TRUE)
+        # Don't show all the dplyr deprecation warnings
+        if (!grepl("dplyr 0.7", m$message)) {
+          html("analyzeProgress", paste0(m$message, "\n"), TRUE)
+        }
       }
     )
     show("analyzeNextMsg")
@@ -21,4 +24,4 @@ observeEvent(input$analyzeBtn, {
 # change to results tab when clicking on link
 observeEvent(input$toResults,
   updateTabsetPanel(session, "mainNav", "resultsTab")
-)
\ No newline at end of file
+)
