@@ -174,3 +174,26 @@ test_that("get_single_well works", {
       dplyr::select(-well)
   )
 })
+
+testdir <- function(dirname) {
+  system.file("sample_data", dirname, package = "ddpcr")
+}
+
+test_that("headers to be skipped are detected", {
+  well_file <- list.files(testdir("read_quant"), pattern = ".*A01.*", full.names = TRUE)
+  legacy_file <- list.files(testdir("read_simple"), pattern = ".*A01.*", full.names = TRUE)
+  meta_file <- list.files(testdir("read_quant"), pattern = "quant.csv", full.names = TRUE)
+  expect_equal(detect_skip(well_file), 4L)
+  expect_equal(detect_skip(legacy_file), 0L)
+  expect_equal(detect_skip(meta_file), 0L)
+})
+
+test_that("attempting to read header-only data file produces an error", {
+  tmp <- tempfile()
+  on.exit({file.remove(tmp)})
+  write("Target Value of 0 = negative", tmp)
+  write("Target Value of 1 = positive", tmp, append = TRUE)
+  write("Target Value of u = unclassified (Advanced Classification Mode)", file = tmp, append = TRUE)
+  write("", file = tmp, append = TRUE)
+  expect_error(detect_skip(tmp), regexp = "without detecting any data")
+})
